@@ -428,11 +428,11 @@ static void
 setup_item_signals (GooCanvasItem *item)
 {
   g_signal_connect (item, "motion_notify_event",
-		    (GtkSignalFunc) on_motion_notify, NULL);
+		    G_CALLBACK (on_motion_notify), NULL);
   g_signal_connect (item, "button_press_event",
-		    (GtkSignalFunc) on_button_press, NULL);
+		    G_CALLBACK (on_button_press), NULL);
   g_signal_connect (item, "button_release_event",
-		    (GtkSignalFunc) on_button_release, NULL);
+		    G_CALLBACK (on_button_release), NULL);
 }
 
 
@@ -478,7 +478,7 @@ create_canvas_primitives ()
 	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 50.00, 0.05, 0.50, 0.50));
 	w = gtk_spin_button_new (adj, 0.0, 2);
 	g_signal_connect (adj, "value_changed",
-			  (GtkSignalFunc) zoom_changed,
+			  G_CALLBACK (zoom_changed),
 			  canvas);
 	gtk_widget_set_size_request (w, 50, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
@@ -492,7 +492,7 @@ create_canvas_primitives ()
 	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 50.00, 0.05, 0.50, 0.50));
 	w = gtk_spin_button_new (adj, 0.0, 2);
 	g_signal_connect (adj, "value_changed",
-			  (GtkSignalFunc) zoom_x_changed,
+			  G_CALLBACK (zoom_x_changed),
 			  canvas);
 	gtk_widget_set_size_request (w, 50, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
@@ -506,7 +506,7 @@ create_canvas_primitives ()
 	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 50.00, 0.05, 0.50, 0.50));
 	w = gtk_spin_button_new (adj, 0.0, 2);
 	g_signal_connect (adj, "value_changed",
-			  (GtkSignalFunc) zoom_y_changed,
+			  G_CALLBACK (zoom_y_changed),
 			  canvas);
 	gtk_widget_set_size_request (w, 50, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
@@ -523,7 +523,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	/*gtk_widget_show (w);*/
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) center_toggled,
+			  G_CALLBACK (center_toggled),
 			  canvas);
 
 	/* Move Ellipse */
@@ -532,7 +532,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) move_ellipse_clicked,
+			  G_CALLBACK (move_ellipse_clicked),
 			  canvas);
 
 	/* Animate Ellipse */
@@ -541,7 +541,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) animate_ellipse_clicked,
+			  G_CALLBACK (animate_ellipse_clicked),
 			  canvas);
 	
 	/* Stop Animation */
@@ -550,7 +550,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) stop_animation_clicked,
+			  G_CALLBACK (stop_animation_clicked),
 			  canvas);
 	
 
@@ -561,7 +561,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) write_pdf_clicked,
+			  G_CALLBACK (write_pdf_clicked),
 			  canvas);
 #endif
 
@@ -569,7 +569,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) change_bounds_clicked,
+			  G_CALLBACK (change_bounds_clicked),
 			  canvas);
 
 	hbox = gtk_hbox_new (FALSE, 4);
@@ -586,21 +586,21 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) scroll_to_50_50_clicked,
+			  G_CALLBACK (scroll_to_50_50_clicked),
 			  canvas);
 
 	w = gtk_button_new_with_label("250,250");
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) scroll_to_250_250_clicked,
+			  G_CALLBACK (scroll_to_250_250_clicked),
 			  canvas);
 
 	w = gtk_button_new_with_label("500,500");
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "clicked",
-			  (GtkSignalFunc) scroll_to_500_500_clicked,
+			  G_CALLBACK (scroll_to_500_500_clicked),
 			  canvas);
 
 	/* Scroll anchor */
@@ -614,7 +614,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_NW));
@@ -624,7 +624,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_N));
@@ -634,7 +634,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_NE));
@@ -644,7 +644,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_W));
@@ -654,7 +654,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_CENTER));
@@ -664,7 +664,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_E));
@@ -674,7 +674,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_SW));
@@ -684,7 +684,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_S));
@@ -694,7 +694,7 @@ create_canvas_primitives ()
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 	g_signal_connect (w, "toggled",
-			  (GtkSignalFunc) anchor_toggled,
+			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
 			   GINT_TO_POINTER (GTK_ANCHOR_SE));
@@ -714,7 +714,7 @@ create_canvas_primitives ()
 
 #if 0
 	g_signal_connect_after (canvas, "key_press_event",
-				(GtkSignalFunc) key_press,
+				G_CALLBACK (key_press),
 				NULL);
 
 	GTK_WIDGET_SET_FLAGS (canvas, GTK_CAN_FOCUS);
@@ -1404,7 +1404,7 @@ setup_canvas (GooCanvas *canvas)
 
   root = goo_canvas_get_root_item (canvas);
   g_signal_connect (root, "button_press_event",
-		    (GtkSignalFunc) on_background_button_press, NULL);
+		    G_CALLBACK (on_background_button_press), NULL);
 
   /* Setup canvas items */
 #if 1
@@ -1441,7 +1441,7 @@ create_window ()
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_default_size (GTK_WINDOW (window), 640, 600);
   gtk_widget_show (window);
-  g_signal_connect (window, "delete_event", (GtkSignalFunc) on_delete_event,
+  g_signal_connect (window, "delete_event", G_CALLBACK (on_delete_event),
 		    NULL);
 
   notebook = gtk_notebook_new ();
